go_dspkg

package module
v0.5.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 17, 2025 License: MIT Imports: 0 Imported by: 0

README

GO - Data Structure PacKaGe

Go (generic) data structures and graph algorithms with a focus on clarity and performance.

  • Go 1.21+
  • Module: github.com/elecbug/go-dspkg

Install

go get github.com/elecbug/go-dspkg@latest

Packages

  • bimap: Bidirectional map with O(1) lookups key->value and value->key.
  • slice: Generic helpers: binary search, stable merge sort, parallel sort, and IsSorted.
  • network-graph: Unweighted network analysis library.

Development

  • Run tests
go test ./...

License

MIT © 2025 elecbug. See LICENSE.

Documentation

Overview

Package go_dspkg provides common types and utilities used across this repository.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Any

type Any = interface{}

Any is an alias for interface{} for convenience.

Directories

Path Synopsis
Package bimap implements a bidirectional map with constant-time lookups from key to value and value to key.
Package bimap implements a bidirectional map with constant-time lookups from key to value and value to key.
network-graph
g-algorithm
Package g_algorithm provides graph algorithms for network analysis.
Package g_algorithm provides graph algorithms for network analysis.
graph
Package graph provides a simple adjacency map graph for network-graph.
Package graph provides a simple adjacency map graph for network-graph.
node
Package node defines node identifiers used in network-graph.
Package node defines node identifiers used in network-graph.
path
Package path defines path structures used by network-graph algorithms.
Package path defines path structures used by network-graph algorithms.
Package slice provides generic slice utilities such as binary search and sorting.
Package slice provides generic slice utilities such as binary search and sorting.

Jump to